@@ -63,7 +63,7 @@ G_BEGIN_DECLS
  *   Colors set by SGR 256-color extension (38/48;5;index).
  *   These are direct indices into the color palette.
  *
- * 256 .. VTE_PALETTE_SIZE - 1 (262):
+ * 256 .. VTE_PALETTE_SIZE - 1 (261):
  *   Special values, such as default colors.
  *   These are direct indices into the color palette.
  *
@@ -71,6 +71,10 @@ G_BEGIN_DECLS
  *   Colors set by legacy escapes (30..37/40..47, 90..97/100..107).
  *   These are translated to 0 .. 15 before looking up in the palette, taking bold into account.
  *
+ * VTE_DIM_COLORS (2^10) .. :
+ *   Dimmed version of the above, for foreground colors.
+ *   Cell attributes can't have these colors.
+ *
  * VTE_RGB_COLOR (2^24) .. VTE_RGB_COLOR + 16Mi - 1 (2^25 - 1):
  *   Colors set by SGR truecolor extension (38/48;2;red;green;blue)
  *   These are direct RGB values.
@@ -80,7 +84,7 @@ G_BEGIN_DECLS
 #define VTE_LEGACY_FULL_COLOR_SET_SIZE	16
 #define VTE_COLOR_PLAIN_OFFSET		0
 #define VTE_COLOR_BRIGHT_OFFSET		8
-#define VTE_COLOR_DIM_OFFSET		16
+#define VTE_DIM_COLOR			(1 << 10)
 #define VTE_RGB_COLOR			(1 << 24)
 /* More color defines in vterowdata.h */
 
@@ -263,7 +267,6 @@ struct _VteTerminalPrivate {
 	VteEraseBinding backspace_binding, delete_binding;
 	gboolean meta_sends_escape;
 	gboolean audible_bell;
-	gboolean visible_bell;
 	gboolean margin_bell;
 	guint bell_margin;
 	gboolean allow_bold;
@@ -434,7 +437,6 @@ void _vte_terminal_set_tabstop(VteTerminal *terminal, int column);
 void _vte_terminal_update_insert_delta(VteTerminal *terminal);
 void _vte_terminal_cleanup_fragments(VteTerminal *terminal, long start, long end);
 void _vte_terminal_audible_beep(VteTerminal *terminal);
-void _vte_terminal_visible_beep(VteTerminal *terminal);
 void _vte_terminal_beep(VteTerminal *terminal);
 PangoColor *_vte_terminal_get_color(const VteTerminal *terminal, int idx);
 void _vte_terminal_set_color_internal(VteTerminal *terminal,
